Package: modeldata
Title: Data Sets Useful for Modeling Examples
Version: 1.5.1
Authors@R: c(
    person("Max", "Kuhn", , "max@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Data sets used for demonstrating or testing model-related
    packages are contained in this package.
License: MIT + file LICENSE
URL: https://modeldata.tidymodels.org,
        https://github.com/tidymodels/modeldata
BugReports: https://github.com/tidymodels/modeldata/issues
Depends: R (>= 4.1)
Imports: cli, dplyr, MASS, purrr, rlang (>= 1.1.0), tibble
Suggests: covr, ggplot2, testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate, tidymodels/tidymodels
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-27
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-21 19:27:19 UTC; max
Author: Max Kuhn [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Max Kuhn <max@posit.co>
Repository: CRAN
Date/Publication: 2025-08-22 06:20:02 UTC
Built: R 4.6.0; ; 2026-04-29 01:37:08 UTC; unix
