# Generated by roxygen2: do not edit by hand

export(sim_classification)
export(sim_logistic)
export(sim_multinomial)
export(sim_noise)
export(sim_regression)
import(rlang)
importFrom(stats,rnorm)
importFrom(stats,runif)
