
<!-- README.md is generated from README.Rmd. Please edit that file -->

# modeldata

<!-- badges: start -->

[![CRAN
status](https://www.r-pkg.org/badges/version/modeldata)](https://CRAN.R-project.org/package=modeldata)
[![R-CMD-check](https://github.com/tidymodels/modeldata/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/tidymodels/modeldata/actions/workflows/R-CMD-check.yaml)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html)
<!-- badges: end -->

`modeldata` contains data sets used in documentation and testing for
tidymodels packages. The package also contains a suite of simulation
functions for classification and regression data.

## Installation

You can install the released version of modeldata from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages("modeldata")
```

And the development version from [GitHub](https://github.com/) with:

``` r
# install.packages("pak")
pak::pak("tidymodels/modeldata")
```

## Contributing

This project is released with a [Contributor Code of
Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html).
By contributing to this project, you agree to abide by its terms.

- For questions and discussions about tidymodels packages, modeling, and
  machine learning, please [post on RStudio
  Community](https://forum.posit.co/new-topic?category_id=15&tags=tidymodels,question).

- If you think you have encountered a bug, please [submit an
  issue](https://github.com/tidymodels/modeldata/issues).

- Either way, learn how to create and share a
  [reprex](https://reprex.tidyverse.org/articles/articles/learn-reprex.html)
  (a minimal, reproducible example), to clearly communicate about your
  code.

- Check out further details on [contributing guidelines for tidymodels
  packages](https://www.tidymodels.org/contribute/) and [how to get
  help](https://www.tidymodels.org/help/).
