#' Example bivariate classification data
#'
#' @details These data are a simplified version of the segmentation data contained
#' in `caret`. There are three columns: `A` and `B` are predictors and the column
#' `Class` is a factor with levels "One" and "Two". There are three data sets:
#' one for training (n = 1009), validation (n = 300), and testing (n = 710).
#'
#' @name bivariate
#' @aliases bivariate_train  bivariate_test bivariate_val
#' @docType data
#' @return \item{bivariate_train, bivariate_test, bivariate_val}{tibbles}
#'
#' @keywords datasets
#' @examples
#' data(bivariate)
#' str(bivariate_train)
#' str(bivariate_val)
#' str(bivariate_test)
NULL
