#' OkCupid text data
#'
#' These are a sample of columns and users of OkCupid dating
#'  website. The data are from Kim and Escobedo-Land (2015).
#'  Permission to use this data set was explicitly granted by
#'  OkCupid. The data set contains 10 text fields filled out by
#'  users. There is an field called `Class` that is a factor with
#'  levels "stem" and "other" where a value of "stem" means that
#'  the user had a job in Science, Technology, Engineering, or
#'  Math.

#'
#' @name okc_text
#' @aliases okc_text
#' @docType data
#' @return \item{okc_text}{a tibble}
#'
#' @source Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
#'   Introductory Statistics and Data Science Courses." *Journal of
#'   Statistics Education: An International Journal on the Teaching and
#'   Learning of Statistics*.
#'
#' @keywords datasets
#' @examples
#' data(okc_text)
#' str(okc_text)
NULL
