#' OkCupid data
#'
#' These are a sample of columns of users of OkCupid dating website. The data
#' are from Kim and Escobedo-Land (2015). Permission to use this data set was
#' explicitly granted by OkCupid.
#'
#' @name okc
#' @aliases okc
#' @docType data
#' @return \item{okc}{a data frame}
#'
#' @source Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
#'   Introductory Statistics and Data Science Courses." *Journal of
#'   Statistics Education: An International Journal on the Teaching and
#'   Learning of Statistics*.
#'
#' @keywords datasets
#' @examples
#' data(okc)
#' str(okc)
NULL
