#' Annual Stack Overflow Developer Survey Data
#'
#' @details These data are a collection of 5,594 data points collected on
#' developers. These data could be used to try to predict who works remotely
#' (as used in the source listed below).
#'
#' @name stackoverflow
#' @aliases stackoverflow
#' @docType data
#' @return \item{stackoverflow}{a tibble}
#'
#' @source
#' Julia Silge, _Supervised Machine Learning Case Studies in R_
#'
#' `https://supervised-ml-course.netlify.com/chapter2`
#'
#' Raw data: `https://insights.stackoverflow.com/survey/`
#' @keywords datasets
#' @examples
#' data(stackoverflow)
#' str(stackoverflow)
NULL
