#' Smithsonian museums
#'
#' Geocodes for the Smithsonian museums (circa 2018).
#'
#' @name Smithsonian
#' @aliases Smithsonian
#' @docType data
#' @return \item{Smithsonian}{a tibble}
#'
#' @source https://en.wikipedia.org/wiki/List_of_Smithsonian_museums
#'
#' @keywords datasets
#' @examples
#' data(Smithsonian)
#' str(Smithsonian)
NULL
