#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom stats rnorm runif
#' @import rlang
## usethis namespace: end
NULL


# needed for simulation docs
utils::globalVariables(
  c(
    ".",
    "linear_pred",
    "non_linear_1",
    "non_linear_2",
    "non_linear_3",
    "outcome",
    "predictor_01",
    "predictor_02",
    "predictor_03",
    "predictor_04",
    "predictor_05",
    "predictor_06",
    "predictor_07",
    "predictor_08",
    "predictor_09",
    "predictor_10",
    "predictor_11",
    "predictor_12",
    "predictor_13",
    "predictor_14",
    "predictor_15",
    "predictor_16",
    "predictor_17",
    "predictor_18",
    "predictor_19",
    "predictor_20",
    "rand",
    "true_prob",
    "two_factor_1",
    "two_factor_2",
    ".truth",
    ".linear_pred",
    ".rand"
  )
)
