#' Palmer Station penguin data
#'
#' A data set from Gorman, Williams, and Fraser (2014) containing measurements
#' from different types of penguins. This version of the data was retrieved from
#' Allison Horst's `palmerpenguins` package on 2020-06-22.
#'
#' @name penguins
#' @aliases penguins
#' @docType data
#' @return \item{penguins}{a tibble}
#' @source Gorman KB, Williams TD, Fraser WR (2014) Ecological Sexual Dimorphism
#' and Environmental Variability within a Community of Antarctic Penguins
#' (_Genus Pygoscelis_). PLoS ONE 9(3): e90081.
#' \doi{10.1371/journal.pone.0090081}
#'
#' \url{https://github.com/allisonhorst/palmerpenguins}
#' @keywords datasets
#' @examples
#' data(penguins)
#' str(penguins)
NULL
