#' Two class data
#'
#' @details There are artificial data with two predictors (`A` and `B`) and
#'  a factor outcome variable (`Class`).
#'
#' @name two_class_dat
#' @aliases two_class_dat
#' @docType data
#' @return \item{two_class_dat}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(two_class_dat)
#' str(two_class_dat)
NULL

#' Two class predictions
#'
#' @details These data are a test set form a model built for two
#'  classes ("Class1" and "Class2"). There are columns for the true
#'  and predicted classes and column for the probabilities for each
#'  class.
#'
#' @name two_class_example
#' @aliases two_class_example
#' @docType data
#' @return \item{two_class_example}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(two_class_example)
#' str(two_class_example)
NULL
