#' Credit data
#'
#' These data are from the website of Dr. Lluís A. Belanche Muñoz by way of a
#' github repository of Dr. Gaston Sanchez. One data point is a missing outcome
#' was removed from the original data.
#'
#' @name credit_data
#' @aliases credit_data
#' @docType data
#' @return \item{credit_data}{a data frame}
#'
#' @source https://github.com/gastonstat/CreditScoring,
#' http://bit.ly/2kkBFrk
#'
#' @keywords datasets
#' @examples
#' data(credit_data)
#' str(credit_data)
NULL
