#' Parabolic class boundary data
#'
#' @details These data were simulated. There are two correlated predictors and
#' two classes in the factor outcome.
#'
#' @name parabolic
#' @aliases parabolic
#' @docType data
#' @return \item{parabolic}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(parabolic)
#' str(parabolic)
NULL
