#' Sample time series data
#'
#' @details Drink sales. The exact name of the series from FRED is:
#' "Merchant Wholesalers, Except Manufacturers' Sales Branches and Offices
#' Sales: Nondurable Goods: Beer, Wine, and Distilled Alcoholic Beverages Sales"
#'
#' @name drinks
#' @aliases drinks
#' @docType data
#' @return \item{drinks}{a tibble}
#'
#' @source The Federal Reserve Bank of St. Louis website https://fred.stlouisfed.org/series/S4248SM144NCEN
#'
#' @keywords datasets
#' @examples
#' data(drinks)
#' str(drinks)
NULL
