#' Raw cover type data
#'
#' These data are raw data describing different types of forest cover-types
#'   from the UCI Machine Learning Database (see link below). There is one
#'   column in the data that has a few difference pieces of textual
#'   information (of variable lengths).
#'
#' @name covers
#' @aliases covers
#' @docType data
#' @return \item{covers}{a data frame}
#'
#' @source https://archive.ics.uci.edu/ml/machine-learning-databases/covtype/covtype.info
#'
#' @keywords datasets
#' @examples
#' data(covers)
#' str(covers)
NULL
