% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/two_class_dat.R
\docType{data}
\name{two_class_example}
\alias{two_class_example}
\title{Two class predictions}
\value{
\item{two_class_example}{a data frame}
}
\description{
Two class predictions
}
\details{
These data are a test set form a model built for two
classes ("Class1" and "Class2"). There are columns for the true
and predicted classes and column for the probabilities for each
class.
}
\examples{
data(two_class_example)
str(two_class_example)
}
\keyword{datasets}
